@@ -7,3 +7,7 @@ def get_dashboard_route(workspace: str) -> str:
 
 def get_project_route(workspace: str, project_name: str) -> str:
     return f"{get_dashboard_route(workspace)}/projects/{project_name}"
+
+
+def get_dataset_route(workspace: str, project_name: str, dataset_id: str) -> str:
+    return f"{get_project_route(workspace, project_name)}/datasets/{dataset_id}"
